/*
	Copyright (C) 2011  Andrew Cotter

	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/


/**
	\file convert_to_node.cc
	\brief Example program which converts a PLY file into a NODE file
*/




#include "data.hh"


#include <ply.hpp>


#include <boost/filesystem.hpp>

#include <boost/shared_array.hpp>
#include <boost/assert.hpp>
#include <boost/static_assert.hpp>


#include <vector>

#include <iostream>

#include <stdexcept>

#include <cstdint>
#include <cstdlib>
#include <cstddef>
#include <cmath>




//============================================================================
//    main function
//============================================================================


/**
	\brief main function

	This program takes one parameter: a filename. This file can be in either
	PLY or NODE format, which will be loaded, and then written to stdout in
	NODE format.
*/
int main( int argc, char* argv[] ) {

	typedef double Type;

	if ( argc != 2 ) {

		std::cerr << argv[ 0 ] << " <filename>" << std::endl;
		exit( EXIT_FAILURE );
	}

	boost::filesystem::path const path( argv[ 1 ] );
	if ( ! boost::filesystem::is_regular( path ) ) {

		if ( ! boost::filesystem::is_regular( path ) )
			std::cerr << '"' << path << "\" does not exist" << std::endl;
		exit( EXIT_FAILURE );
	}

	try {

		// read the points
		unsigned int dimension = 0;
		std::vector< boost::shared_array< Type > > pPoints;
		ReadFile( dimension, pPoints, path );

		// write the new node file
		std::cout << pPoints.size() << ' ' << dimension << " 0 0" << std::endl;
		for ( unsigned int ii = 1; ii <= pPoints.size(); ++ii ) {

			std::cout << ii;
			for ( unsigned int jj = 0; jj < dimension; ++jj )
				std::cout << ' ' << std::fixed << pPoints[ ii - 1 ][ jj ];
			std::cout << std::endl;
		}
	}
	catch( std::exception& error ) {

		std::cerr << error.what() << std::endl;
		exit( EXIT_FAILURE );
	}

	return EXIT_SUCCESS;
}
